package net.knarcraft.bookswithoutborders;

import org.bukkit.ChatColor;

/**
 * Class for getting various settings
 */
public class BooksWithoutBordersSettings {

    //Static settings
    private static final ChatColor errorColor = ChatColor.RED;
    private static final ChatColor successColor = ChatColor.GREEN;
    private static final ChatColor commandColor = ChatColor.YELLOW;
    private static final String SLASH = System.getProperty("file.separator");
    private static boolean isInitialized;
    public static String bookFolder;

    /**
     * Initializes the books without borders settings class
     *
     * @param booksWithoutBorders <p>The books without borders object used for getting required data</p>
     */
    public static void initialize(BooksWithoutBorders booksWithoutBorders) {
        if (isInitialized) {
            throw new IllegalArgumentException("Settings class initialized twice. This should not happen!");
        }
        isInitialized = true;
        bookFolder = booksWithoutBorders.getDataFolder().getAbsolutePath() + getSlash() + "Books" + getSlash();
    }

    /**
     * Gets the folder used for storing books
     *
     * @return <p>The folder used for storing books</p>
     */
    public static String getBookFolder() {
        return bookFolder;
    }

    /**
     * Gets the color to use for error messages
     *
     * @return <p>The color to use for error messages</p>
     */
    public static ChatColor getErrorColor() {
        return errorColor;
    }

    /**
     * Gets the color to use for success messages
     *
     * @return <p>The color to use for success messages</p>
     */
    public static ChatColor getSuccessColor() {
        return successColor;
    }

    /**
     * Gets the color used to color commands
     *
     * @return <p>The color used to color commands</p>
     */
    public static ChatColor getCommandColor() {
        return commandColor;
    }

    /**
     * Gets the correct slash to use for the used OS
     *
     * @return <p>The slash to use for file separators</p>
     */
    public static String getSlash() {
        return SLASH;
    }


}
